@@ -5,7 +5,7 @@ rm -f units/*/*
 
 # Clean up components output directories
 rm -rf components/chsdet/lib/*
-rm -rf components/dcpcrypt/lib/*
+rm -rf components/kascrypt/lib/*
 rm -rf components/doublecmd/lib/*
 rm -rf components/gifanim/lib/*
 rm -rf components/Image32/lib/*
@@ -27,10 +27,12 @@ find plugins -iname '*.a'  -delete
 rm -f src/doublecmd.res doublecmd
 rm -f tools/extractdwrflnfo
 rm -f plugins/wcx/unrar/lib/rarconfdlg.lfm
+rm -f plugins/wcx/unrar/lib/rarlng.rsj
 rm -f plugins/wcx/zip/lib/ZipConfDlg.lfm
 rm -f plugins/wcx/zip/lib/ZipLng.rsj
 rm -f plugins/wcx/zip/lib/abresstring.rs?
 rm -f plugins/wfx/ftp/lib/FtpConfDlg.lfm
+rm -f plugins/wfx/ftp/lib/ftppropdlg.lfm
 rm -f plugins/wfx/samba/lib/smbauthdlg.lfm
 
 # Remove debug files
